from bergen.query import DelayedGQL





CREATE_SAMPLE = DelayedGQL("""
mutation SampleCreate($name: String, $creator: String) {
  createSample(name: $name, creator: $creator){
    id
    name
    creator {
        email
    }
  }
}
""")




from bergen.query import DelayedGQL


GET_SAMPLE = DelayedGQL("""
query Sample($id: ID!){
  sample(id: $id){
    id
    name
  }
}
""")


FILTER_SAMPLE = DelayedGQL("""
query Samples($creator: ID) {
  samples(creator: $creator) {
    name
    id
    representations {
        id
    }
  }
}
""")




from bergen.query import DelayedGQL


FILTER_REPRESENTATION = DelayedGQL("""
query Representation($name: String) {
  representations(name: $name) {
    id
    name
    store
    variety
    tags
    unique
    creator {
      email
    }
    sample {
      id
    }
  }
}
""")

GET_REPRESENTATION = DelayedGQL("""
query Representation($id: ID!){
  representation(id: $id){
    id
    name
    tags
    variety
    store
    unique
    creator {
      email
    }
    sample {
      id
    }
  
  }
}
""")


from bergen.types.model import ArnheimAsyncModelManager, ArnheimModelManager
from concurrent.futures import ThreadPoolExecutor
import asyncio


class RepresentationManager(ArnheimModelManager["Representation"]):

    def from_xarray(self, array, compute=True, **kwargs):
        instance = self.create(**kwargs)
        instance.save_array(array, compute=compute)
        instance = self.update(id=instance.id, **kwargs)
        return instance


class AsyncRepresentationManager(ArnheimAsyncModelManager["Representation"]):

    async def from_xarray(self, array, compute=True, **kwargs):
        instance = await self.create(**kwargs)
        with ThreadPoolExecutor(max_workers=1) as executor:
            co_future = executor.submit(instance.save_array, array, compute=True)
            await asyncio.wrap_future(co_future)    
        instance = await self.update(id=instance.id, **kwargs)
        return instance